(function($){
  var loaded;

  function onLoad() {    
    loaded = true;
  }
  
  if (!google.feeds) {
    google.setOnLoadCallback(onLoad);
    google.load("feeds", "1");    
  }

  
  $.fn.displayRSS = function(urls, opts) {     
      if(!opts) {
        opts = {}
      }
      
      var $this = $(this);
      
      var onLoad = function() {

        if (google) {

          clearInterval(loadInterval);  
          var _f = Feedinator($this, urls, opts);
          _f.init();  
        }
      }
      var loadInterval = setInterval(onLoad, 500);
          
      // var _f = Feedinator(this, urls, opts);
      // google.setOnLoadCallback(_f.init);
           
      return $this;      
  }


  var Feedinator = function(element, urls, opts) {

    var data = [];
    var loadCount = 0;
    var interval;

    var template = '<a href="{link}">{title}</a>';
    if (opts.template) {
      template = opts.template;
    }

    var dateFormatMask = 'htt dd mmmm yyyy';
    if (opts.dateFormat) {
      dateFormatMask = opts.dateFormat;
    }

    var numberOfItems = 5;
    if (opts.numberOfItems) {
      numberOfItems = opts.numberOfItems;
    }

    var listItemClass = '';
    if (opts.listItemClass) {
      listItemClass = opts.listItemClass;
    }


    var renderer = function(entry) {
  		var html = template.replace(/{link}/g, entry.link);
  		html = html.replace(/{title}/g, entry.title)
  		html = html.replace(/{content}/g, entry.content)
      try {
        var publishedDate = new Date(Date.parse(entry.publishedDate));
        html = html.replace(/{publishedDate}/g, publishedDate.format(dateFormatMask));
      } catch(ex) {      
  		  html = html.replace(/{publishedDate}/g, "");
      }   
      return html; 
    }


    var load = function() {
      $.each(urls, function(index, url) {          
        var feed = new google.feeds.Feed(url);
        feed.setNumEntries(numberOfItems);
        feed.load(function(result) {
          if (!result.error) {
            data = data.concat(result.feed.entries);
            loadCount++;
          }
        });
      });
      interval = setInterval(onLoad, 500);     
    }

    var onLoad = function() { 
      if(loadCount == urls.length) {
        clearInterval(interval);
        entries = sortByPublishedDate(numberOfItems);
        display(entries);
        if (opts.onComplete) {
          opts.onComplete();
        }
      }
    }

    var display = function(entries) {
  		$(element).empty();
  		$.each(entries, function(index, entry) {
        appendEntry(entry);
  		});		
    }

    var appendEntry = function(entry) { 
      var html = renderer(entry);

      if (opts.renderer) {
        html = opts.renderer(entry, html);
      }
      $(element).append( $('<li>').addClass(listItemClass).append(html) );
    }

    var sortByPublishedDate = function(count) {
  		data.sort(function(entryA,entryB){
  		  return new Date(entryB.publishedDate) - new Date(entryA.publishedDate);
  		});	
  		return data.slice(0, count);
    }

    return {
      init: function() {
        if (typeof urls == "string") {
          urls = [urls]
        }
        load(); 
      }    
    }

  }


  /*
   * Date Format 1.2.3
   * (c) 2007-2009 Steven Levithan <stevenlevithan.com>
   * MIT license
   *
   * Includes enhancements by Scott Trenda <scott.trenda.net>
   * and Kris Kowal <cixar.com/~kris.kowal/>
   *
   * Accepts a date, a mask, or a date and a mask.
   * Returns a formatted version of the given date.
   * The date defaults to the current date/time.
   * The mask defaults to dateFormat.masks.default.
   */
  var dateFormat = function () {
  	var	token = /d{1,4}|m{1,4}|yy(?:yy)?|([HhMsTt])\1?|[LloSZ]|"[^"]*"|'[^']*'/g,
  		timezone = /\b(?:[PMCEA][SDP]T|(?:Pacific|Mountain|Central|Eastern|Atlantic) (?:Standard|Daylight|Prevailing) Time|(?:GMT|UTC)(?:[-+]\d{4})?)\b/g,
  		timezoneClip = /[^-+\dA-Z]/g,
  		pad = function (val, len) {
  			val = String(val);
  			len = len || 2;
  			while (val.length < len) val = "0" + val;
  			return val;
  		};

  	// Regexes and supporting functions are cached through closure
  	return function (date, mask, utc) {
  		var dF = dateFormat;

  		// You can't provide utc if you skip other args (use the "UTC:" mask prefix)
  		if (arguments.length == 1 && Object.prototype.toString.call(date) == "[object String]" && !/\d/.test(date)) {
  			mask = date;
  			date = undefined;
  		}

  		// Passing date through Date applies Date.parse, if necessary
  		date = date ? new Date(date) : new Date;
  		if (isNaN(date)) throw SyntaxError("invalid date");

  		mask = String(dF.masks[mask] || mask || dF.masks["default"]);

  		// Allow setting the utc argument via the mask
  		if (mask.slice(0, 4) == "UTC:") {
  			mask = mask.slice(4);
  			utc = true;
  		}

  		var	_ = utc ? "getUTC" : "get",
  			d = date[_ + "Date"](),
  			D = date[_ + "Day"](),
  			m = date[_ + "Month"](),
  			y = date[_ + "FullYear"](),
  			H = date[_ + "Hours"](),
  			M = date[_ + "Minutes"](),
  			s = date[_ + "Seconds"](),
  			L = date[_ + "Milliseconds"](),
  			o = utc ? 0 : date.getTimezoneOffset(),
  			flags = {
  				d:    d,
  				dd:   pad(d),
  				ddd:  dF.i18n.dayNames[D],
  				dddd: dF.i18n.dayNames[D + 7],
  				m:    m + 1,
  				mm:   pad(m + 1),
  				mmm:  dF.i18n.monthNames[m],
  				mmmm: dF.i18n.monthNames[m + 12],
  				yy:   String(y).slice(2),
  				yyyy: y,
  				h:    H % 12 || 12,
  				hh:   pad(H % 12 || 12),
  				H:    H,
  				HH:   pad(H),
  				M:    M,
  				MM:   pad(M),
  				s:    s,
  				ss:   pad(s),
  				l:    pad(L, 3),
  				L:    pad(L > 99 ? Math.round(L / 10) : L),
  				t:    H < 12 ? "a"  : "p",
  				tt:   H < 12 ? "am" : "pm",
  				T:    H < 12 ? "A"  : "P",
  				TT:   H < 12 ? "AM" : "PM",
  				Z:    utc ? "UTC" : (String(date).match(timezone) || [""]).pop().replace(timezoneClip, ""),
  				o:    (o > 0 ? "-" : "+") + pad(Math.floor(Math.abs(o) / 60) * 100 + Math.abs(o) % 60, 4),
  				S:    ["th", "st", "nd", "rd"][d % 10 > 3 ? 0 : (d % 100 - d % 10 != 10) * d % 10]
  			};

  		return mask.replace(token, function ($0) {
  			return $0 in flags ? flags[$0] : $0.slice(1, $0.length - 1);
  		});
  	};
  }();

  // Some common format strings
  dateFormat.masks = {
  	"default":      "ddd mmm dd yyyy HH:MM:ss",
  	shortDate:      "m/d/yy",
  	mediumDate:     "mmm d, yyyy",
  	longDate:       "mmmm d, yyyy",
  	fullDate:       "dddd, mmmm d, yyyy",
  	shortTime:      "h:MM TT",
  	mediumTime:     "h:MM:ss TT",
  	longTime:       "h:MM:ss TT Z",
  	isoDate:        "yyyy-mm-dd",
  	isoTime:        "HH:MM:ss",
  	isoDateTime:    "yyyy-mm-dd'T'HH:MM:ss",
  	isoUtcDateTime: "UTC:yyyy-mm-dd'T'HH:MM:ss'Z'"
  };

  // Internationalization strings
  dateFormat.i18n = {
  	dayNames: [
  		"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat",
  		"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"
  	],
  	monthNames: [
  		"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec",
  		"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"
  	]
  };

  // For convenience...
  if (!Date.prototype.format) {
    Date.prototype.format = function (mask, utc) {
     return dateFormat(this, mask, utc);
    };
  }  

})(jQuery);



